#ifndef TWOMASSCNVRT_H
#define TWOMASSCNVRT_H

#include <string>

/*
ASCII format in the input files
blank-separated ra, dec, name, J, H, K,flags,flags

ASCII format in the output file:
blank separated 100, xpx ypx, magnitude

convert alt,az given phi to delta and hour angle
cos(delta)*sin(h) = cos a*cosA
cos(delta)*cos(h) = sin a*cos phi + cos a *cos A*sin phi

hour angle= GST-lambda(observer,west=positive!)-alpha

output WCS
alt, az, h, RA, delta, OBSGEO-
*/

class TwoMassCnvrt {
public:
	/** 2-sided field-of-viewk, expressed as the edge of
	* the full detector in units of pixels. We only consider
	* quadratic detectors. For a single Hawii2 chip, this is
	* 2048, for example.
	*/
	int detsize ;

	/** Pixel scale in the FITS image [rad/px].
	* Obtained from the [arcsec/px] number by multiplication with pi/(180*3600).
	*/
	float px ;

	/** Directory of 2MASS catalog with the xxx/t*.cat * files.
	* For example "tmc1" indicates that tmc1/000/t*.cat up to tmc1/189/t*.cat
	* are the files that have been processed by the tmcat expander.
	*/
	std::string catDir ;

	TwoMassCnvrt(int detsiz, float pixsc, const std::string catdir) ;

	void skymakeList(double ra, double decl, float maglim, char band, float q, const bool geirs) const ;

	void wcs(double ra, double decl) const ;

	void spdRange(double decl, int spd[2]) const ;

	float mag2mag(float magI, int magidx, float q=1.) const ;

	std::string alpha2hex(double alpha) const;
	std::string deg2hex(double delta) const;

	static double hex2deg(const std::string & hexstr, bool isdeg) ;
protected:
	bool tanProj(double ra, double decl, double radec[2], int xy[2]) const ;

private:
} ;
#endif
